import 'package:flutter/material.dart';
import 'package:flutter_helper/flutter_helper.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:image_picker/image_picker.dart';

class VideoPickerView extends ConsumerStatefulWidget {
  final Future<void> Function(XFile) onVideoPicked;
  final String url;
  final String label;

  const VideoPickerView({required this.onVideoPicked, required this.url, required this.label});

  @override
  _VideoPickerViewState createState() => _VideoPickerViewState();
}

class _VideoPickerViewState extends ConsumerState<VideoPickerView> {
  bool _isLoading = false;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: ChildrenUtil().getAllPaddedChildren([
        Text(widget.label),
        if (_isLoading) CircularProgressIndicator()
        else if (widget.url != "") SizedBox(
            width: 200,
            height: 200,
            child: UrlVideoPlayerView(url: widget.url)),
        TextButton(onPressed: () async {
          final XFile? file = await ImagePicker().pickVideo(source: ImageSource.gallery);

          if (file != null) {
            setState(() {
              _isLoading = true;
            });

            await widget.onVideoPicked(file);

            setState(() {
              _isLoading = false;
            });
          }
        }, child: Text(widget.url == "" ? "Add video" : "Change video")),
      ], isOutside: false),
    );
  }
}
